WaapiLocation class
Represents a location object to be sent.
تمثل كائن موقع ليتم إرساله.
Constructors
- WaapiLocation({required double latitude, required double longitude, required String name, required String address})
Properties
- address → String
-
Address of the location (details).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitude → double
-
Latitude of the location.
final
- longitude → double
-
Longitude of the location.
final
- name → String
-
Name of the location (title).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited